@@ -47,8 +47,9 @@ def send_sqs_message(to_sqs_url, queue_name, msg_body, region_name):
     sqs_client = boto3.client('sqs', region_name=region_name)
 
     if queue_name != "":
-        queue = sqs_client.get_queue_by_name(QueueName=queue_name)
-        msg = queue.send_message(MessageBody=json.dumps(msg_body))
+        queue_url = sqs_client.get_queue_url(QueueName=queue_name)
+        msg = sqs_client.send_message(QueueUrl=queue_url,
+                                      MessageBody=json.dumps(msg_body))
 
     else:
         try:
